package com.jthomas.mailfaces;

/*
 * FaceAudio.java
 * Copyright (c) 1996-1998 John Thomas  jthomas@cruzio.com
 *      All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for non-commercial purposes
 * is hereby granted provided that this copyright notice
 * appears in all copies.
 *
 */


import java.util.*;
import java.applet.*;
import java.net.*;
import java.io.*;
import sun.applet.AppletAudioClip;
import com.jthomas.util.*;
/**
 * FaceAudio runs as a separate Thread and accepts 
 * requests to play an audio file (*.au) that is 
 * pointed to by a URL.
 * 
 */
public 
class FaceAudio  implements Runnable {

	// Singleton Class Reference to the instance
private static FaceAudio	_FaceAudio;	 

private	Queue		_Queue;

/**
** _Active is true if the Options file specifies AudioSupport true
*/
private boolean		_Active = false;

/**
 
 *
 * The FaceAudio object is a Singleton and its
 * constructor is called by MailFaces initialization() 
 * It creates a queue that other components can place audio 
 * requests using the queuePut(String url) method.
 */
public
FaceAudio() {
	_Queue = new Queue(16);
	_FaceAudio = this;
	
}




//---------------------------------------
/**
 * run() method will wait for audio requests and play them.
 *
 *  <p>
 * The run() method is given control when the thread is
 * started.  It will get requests from the Queue which 
 * are urls that represent an audio .au file.  
 * It will invode the play(url) method to actually 
 * play the audio.
 *  <p>
 * 
 */
// ----------------------------------------

public void
run()	{
	String audiourl;
	_Active = FaceOptions.getRef().getBoolean("AudioSupport",true);
	if ( _Active ) 
		Debug.out("FaceAudio.run():");
	else {
		Debug.out("FaceAudio is not active");
		return;
	}
	
	try {
		while (true) {			
			audiourl = (String)_Queue.get();
			Debug.out("Playing " + audiourl);
			play(audiourl);
		}
	} catch (Throwable e) {
		Debug.out("FaceAudio: Exception in run(); ",e );
	} finally {
		Debug.out(0,"Audio support is not available");
		_Active = false;
		//System.exit(1);    // So we are forced to know about this!! remove at release ???
	}
	 
}



/**
 * queuePut is used by other objects to place an audiourl String into the FaceAudio work queue.
 *
 */
public void
queuePut(Object obj) {
	if ( _Active) 
		_Queue.put(obj);
}

//-----------------------------------------------
/** 
 * play(urlstr) will play the audio pointed to by the URL.
 *
 * <p>
 * This uses the Sun AppletAudioClip class to play the
 * audio file.
 * @see AppletAudioClip
 */
//-----------------------------------------------
private void
play(String urlstr) {
	URL		audioURL=null;
	AudioClip	audioClip;
 	String filename = null;
    if ( urlstr.startsWith("file:./" ) ) 
	    filename = urlstr.substring(7);  // Remove the "file:./" from front
    if ( urlstr.startsWith("file:" ) ) {
	    filename = urlstr.substring(5);  // 
	    while (filename.startsWith("/")) 
	    	filename = filename.substring(1);
	} else {
		MsgDialog.create("Audio file " + urlstr + " must be a local file.");
    	return;
    }

    File file = new File(filename);
    if (file.exists()) 
    	urlstr = "file:///" + file.getAbsolutePath().replace(File.separatorChar,'/');
    else {
    	MsgDialog.create("Selected local audio file " + urlstr + "does not exist.");
    	return;
    }
    Debug.out("url="+urlstr+" filename="+filename);

    try {
    	Debug.out(urlstr);
    	audioURL = new URL(urlstr);
    } catch (MalformedURLException e) {
    	MsgDialog.create("Invalid Audio specification:\n  "  + urlstr );
    }

    

    if (audioURL != null) {
    	Debug.out(audioURL.toString());
    	//audioClip = new AppletAudioClip(audioURL);
    	audioClip = new AppletAudioClip(audioURL);

		audioClip.play();
		try {Thread.sleep(5000);} catch(Exception e) {}
	
    } else
		MsgDialog.create("Null Audio specification:\n  "  + urlstr );
    
}


/**
** Adding main allows us to to little unit testing
*/

//public static void
//main(String[] argv) {
//	Debug.setDebugOn(true);
//	String url = "file:///d:/javacode/javafaces20/images/chirp.au";
//	
//	if ( argv.length > 0) 
//		url = argv[0];
//	
//	FaceAudio fa = new FaceAudio();
//	fa.play(url);
//}

} // End of class FaceAudio