package com.jthomas.mailfaces;
/*
 * FaceExit.java
 * Copyright (c) 2002 John Thomas  jthomas@cruzio.com
 *      All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for non-commercial purposes
 * is hereby granted provided that this copyright notice
 * appears in all copies.
 *
 */
import java.util.Properties;
import java.util.StringTokenizer;

import javax.mail.Address;
import javax.mail.Message;
import javax.mail.MessagingException;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

import com.jthomas.util.Debug;
import com.jthomas.util.Log;

/**
 *
 * FaceExit is an example of an exit that can be 
 * specified by the user to handle specific requirements.
 * <p>
 * It is given control from the FaceSelect.selectImage method
 * when a Selection statement is matched that contains the 
 * keyword "exit" or "exit(class)".
 * <p>
 * This example will allow the user to send an email with 
 * the subject set to "set sms=on" or "set sms=off" 
 * to change the SMS active option. It would require a 
 * faces.opt statement like: 
 * <pre>
 *  DefaultExit "com.jthomas.mailfaces.FaceExit"
 *  Select sender "me@myisp.com"	"file:./images/me.gif" exit
 * </pre>
 * <p>
 * To replace this exit with your own code: <br>
 * - extend this class and replace the process method with 
 *   your own code<br>
 * - change the classpath to pickup your class file.<br>
 * - change the "DefaultExit" statement in the faces.opt file
 *   or specify it on the exit keyword in the Select statement.
 *   
 * <pre>
 *    ...
 *    public class MyFaceExit extends com.jthomas.mailfaces.FaceExit {
 *    ...
 *    
 *   DefaultExit  MyFaceExit 
 * </pre>
 * 
 * @author	John Thomas
 * <a href="mailto:jthomas@cruzio.com>jthomas@cruzio.com</a>
 * @version	2.1 ( April 2002) 
 */

public class FaceExit {


  //-------------------------
  // Class variables
  //-------------------------	

  //---------------------------
  // Instance variables
  //---------------------------
  /**
   * reference to Mailfaces instance
   */
  private MailFaces _MailFaces;
  
  /**
   * reference to the Options 
   */
  private FaceOptions _Options;
  

  
  /**
  ** Default constructor for FaceExit.
  **
  ** It will processs the Options, ask to be informed if the 
  ** options change, .
  */

  public FaceExit() {
    Debug.out("FaceExit.constructor()");
    _MailFaces = MailFaces.getRef();
    _Options = _MailFaces.getFaceOptionsRef();
    // Process the Options
    refreshOptions();
    // ask to be informed if the Options get changed
    _MailFaces.addFaceEventListener(new FaceEventListener() {
      public void actionPerformed(FaceEvent e) {
        if (e.getID() == FaceEvent.ID_OPTIONS_CHANGED)
          FaceExit.this.refreshOptions();
      }
    });

 

  }
  
  
  //-----------------------------------------------------
  /**
   *Method: refreshOptions() get control initially and when the 
   * user refreshes the Option file.
   *
   * 
   *
   *@return void
   */
  //-----------------------------------------------------

  private void refreshOptions() {
    //Debug.out("FaceExit:refreshOptions()");
    
    //something = _Options.get("Something", null);

  }

  
  //-----------------------------------------------------
  /**
   * process the specified Mailmsg. 
   * 
   * This example of a FaceExit class will allow the user 
   * to turn on or off the SMS option 
   * by sending it email with the subject = "set sms on/off" 
   * So if the user forgets to set the option before they leave the desktop,
   * they could send it as a remote mail to change the option.  
   * 
   * <p>
   * @param mailmsg The instance of Mailmsg 
   * @param selection  The instance of the Select statement that 
   *                    contained the exit parameter 
   * @return void
   */
  //-----------------------------------------------------

  public void process(Mailmsg  mailmsg,FaceSelection selection) {
    

    Debug.out("FaceExit:process: "+mailmsg);
    try {
      FaceSMS faceSms = _MailFaces.getFaceSMSRef();
      String subject = mailmsg.getHeader("subject").toLowerCase();
      if (subject.startsWith("set sms")) {
        if (subject.indexOf("on") > 0) {        
          faceSms.setSMSActive(true);
        } else if (subject.indexOf("off") > 0) {       
          faceSms.setSMSActive(false);
        } else {
          return;
        }
      } else {
        return;
      }
      mailmsg.setSMS(true);   // cause a msg to be sent to cellphone
      mailmsg.setText("SMS option changed to "+faceSms.getSMSActive());
      Debug.out("FaceExit:process: "+"SMS option changed to "+faceSms.getSMSActive() );
    } catch (Exception e) {
      Debug.out(0,e);
    }
  }


  
//  public static void main(String[] args) {
//  }
}
