package com.jthomas.mailfaces;

/*
 * FaceProperties.java
 * Copyright (c) 1996 John Thomas  jthomas@cruzio.com
 *      All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for non-commercial purposes
 * is hereby granted provided that this copyright notice
 * appears in all copies.
 *
 */
import com.jthomas.util.Debug;

import java.io.*;
import java.util.*;

/**
 * FaceProperties  Extends Properties object defined by Sun Util Package.
 *
 * <p>
 *
 * Class to Manage various envirment properties for MailFaces
 *   
 *
 * <p>
 
 *
 * @author	John Thomas
 * <a href="mailto:jthomas@cruzio.com>jthomas@cruzio.com</a>
 * @version	1.0 ( Dec 1996 )
 *
 */ 


public class FaceProperties extends Properties {

private static FaceProperties	_Properties;
private static String			_Filename;

public
FaceProperties() {
    super();

}

//------------------------------------------------------
/**
**    Class method to create a global Properties object
**    for this application.  If the specified file does
**    not exist, then a one is created that contains only 
**    the current Version.
**
** @return FaceProperties object 
*/
//------------------------------------------------------

public static FaceProperties
create(String filename) {

	_Filename = filename;
	File propFile;
    //----------------------------------------------------------
	// There should only be one Property object for the application
	// so warn if there is already one created  (then go ahead and overlay it)
	//-----------------------------------------------------
	if (_Properties != null) {
		Debug.out("FaceProperties.create(): Warning.  Already created.");
	}
		
	_Properties = new FaceProperties();
    try {
		propFile = new File(_Filename);
	    
		if ( propFile.exists() ) {				
			_Properties.load(new FileInputStream(propFile));
		}  else {
			_Properties.put("Version", MailFaces.version());
			_Properties.save();			// create a new file
		}
			
    } catch (Exception e) {
    	Debug.out("FaceProperties: " + e.getMessage());
    	return _Properties;    
    }
    return _Properties;
}

//---------------------------------------
/**
**   Class method to access the reference to the FaceProperty object
*/
//----------------------------------------
public static FaceProperties
getRef()	{
	return _Properties;
}

	
//----------------------------------
/**
**  Write the current set of values to 
**  the properties file
*/
//--------------------------------

public synchronized void
save()	{
	//Debug.out("save");
	//this.list(System.out);
	String header = "#MailFaces Initialization file";
	try {
		super.save(new FileOutputStream(_Filename), header);
		
    } catch (Exception e) {
    	Debug.out("FaceProperties.save(): " + e.getMessage());
    }

}
//-----------------------------------------------------
/**
** Adding this makes this class self-testing
*/
//-----------------------------------------------------
public static void
main(String args[]) {
		
    Debug.setDebugOn(true);
    FaceProperties properties;

    properties = FaceProperties.create("a.ini");
    String test1 = properties.getProperty("Test1");
    Debug.out("Test1=" + test1);
    properties.put("Test1", "This is a test");
    FaceProperties.getRef().put("Test2","This is another test");
    properties.save();
}

}  // End of FaceProperties class