package com.jthomas.mailfaces;


import java.awt.*;
import com.jthomas.util.*;

/**
 * FaceScrollablePanel   extends ScrollPane
 * to provide a Scrollable Panel that will maintain a size that
 * will fit a number of Icons between a min and max count. 
 *
 * @author	John Thomas
 * <a href="mailto:jthomas@cruzio.com>jthomas@cruzio.com</a>
 * @version	1.0 ( Nov 1996 )
 *
 * @see FaceBoard
 */
//--------------------------------------------------------------------------------
class FaceScrollablePanel extends ScrollPane {
        
private Panel	_InnerPanel;
private	int		_ShowMin;
private	int		_ShowMax;
private int		_Number;
private int		_Width;
private int		_Height;
private	int		_Increment;


/**
** Construct a ScrollPane 
**
**@param p - Panel that will be displayed in this ScrollPane
**@param width - Width of an Icon
**@param height - Hieght of an Icon
**@param min - Minimum number of Icons that space should be reserved for.
**@param max - Maximum number of Icons that can be shown without scrolling.
*/

public
FaceScrollablePanel(Panel p, int width, int height, int min, int max) {
 	super();
 	_Width = width;
 	_Height = height;
	_ShowMin = min;
	_ShowMax = max;
	_Number = 0;
	
    _InnerPanel = p;	// This is the panel that we will scroll
    add(_InnerPanel);   // Make it our only component
    this.setSize(this.getMinimumSize());
    this.setVisible(true);
    //doLayout();	
    _Increment = width;  // So we scroll a full icon each time.
    Adjustable adj = this.getHAdjustable(); 
    adj.setUnitIncrement(_Increment);
}



/**
** Sets the current number of unique icons
** Also if there are scrollbars on the window 
** (or will be) then it sets the scroll increment
** so that the new icon will be displayed.
**
**@param new number of icons that will be displayed.
*/
public void
setNumber(int number) {
	int old = _Number;   // save previous value
	_Number = number;
	// Adjust the scrollbar so the new icon is visible
	if (_Number > old && _Number > _ShowMax ) {
		// The 1.1.6 version of Java JDK has problems
		// with the scroll bar adjustment.  
		// The doLayout and validate should not be 
		// be required but it seems to make it work.
		// together with some code in FaceBoard paint
		// method that also sets the ScrollPosition
		//
    	Adjustable adjust = this.getHAdjustable();
    
 		//int oldv = adjust.getValue();
    	int v = (_Number-_ShowMax)*adjust.getUnitIncrement();
    	//Debug.out(oldv+";"+v+";"+adjust);
    	adjust.setValue(v);
    	this.setScrollPosition(v,0);
    	  
		this.validate();
		this.doLayout();  
    	//int newv = adjust.getValue();
    	//Debug.out(newv+";"+adjust);
    }
}



 
/**
** Sets the Maximum number of icons that the user wants
** to display without scrolling
*/
public void
setMax(int max) {
	_ShowMax = max;
}

/**
** Calculates the ScrollPane dimensions
*/

public Dimension
getMinimumSize() {
	Debug.out("FaceScrollablePanel.getMinimumSize()");
	int width = 0;
	int height = 0;
    if (_Number > _ShowMax) {     	
    	width = (_Increment * _ShowMax)+FaceBoard.HGAP;        
    	height = _Height + getHScrollbarHeight()+FaceBoard.VGAP;
    } else {
    	if ( _Number > _ShowMin ) {
    		width = _Increment*(Math.min(_Number,_ShowMax))+FaceBoard.HGAP;
    		height = _Height+FaceBoard.VGAP;
    	}   else {	 
    		width = _Increment*(Math.max(_Number,_ShowMin))+FaceBoard.HGAP;
    		height = _Height+FaceBoard.VGAP;
    	}
    }
	Debug.out("n="+_Number+ " w="+width+" h="+height);			
	return new Dimension(width, height);
}

/**
** Calculates the ScrollPane dimensions
*/

public Dimension
getPreferredSize() {
    //Debug.out("PreferredSize");
	return getMinimumSize();
}

}		// end of FaceScrollablePanel class