package com.jthomas.mailfaces;
/*
 * MailList.java
 * Copyright (c) 1996-1998 John Thomas  jthomas@cruzio.com
 *      All Rights Reserved.
 *
 * Permission to use, copy, modify, and distribute this software and
 * its documentation for non-commercial purposes
 * is hereby granted provided that this copyright notice
 * appears in all copies.
 *
 */
 
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.util.*;
import com.jthomas.util.*;

import javax.mail.Part;
import javax.mail.Multipart;
/**
** Display a dialog that shows the Mailmsgs that are associated with
** a Picon and alllow the user to delete one or more of them.
** Although this looks like a dialog, it implemented just as 
** a normal frame to avoid any of the problems with modal dialogs.
** We do not want the display of this window to 
** prevent other actions.
** 
** @author	John Thomas <a href="mailto:jthomas@cruzio.com">jthomas@cruzio.com</a>
** @version	2.0 ( May 1998 )
*/

public class MailList extends Frame {

// Class variables
	
static final int NUMSHOW=10;   // Number of entries before scroling needed

// state variables

private MailListEntry[]  _MailListEntries;
//private Scrollbar	_Scrollbar;
private ScrollPane	_ScrollPanel;

private boolean 	_DeleteSupported;

/** 
 * if true then display text for message
 */
private boolean   _ShowText = false;

/** 
 * if true then display all headers for message
 */
private boolean   _ShowHeaders = false;

/**
 * reference to an open spawned MailList dialog
 */
private  MailList  _MailList = null;

/**
 * array of Mailmsgs being listed.
 */
private  Mailmsg[]  _Mailmsgs = null;

/**
 * Mailmsg being displayed.
 */
private  Mailmsg  _Mailmsg = null;
/**
** default constructor is not used
*/
private
MailList() {}

/**
** This constructor is used to list all Mailmsgs for all faces 
** 
** @param mailmsgs array of mail messages to display.
*/
public
MailList(Mailmsg[] mailmsgs) {
	super("List of all Mail");
	
	setup(mailmsgs);
	setLocation(10,10);
    show();    // show the results on the screen

	}
	
/**
** This constructor is used to list specific MailMsgs 
* with the text or headers 
* 
* 
** @param mailmsgs array of mail messages to display.
*  @param showText true if tex of message should be displayed 
*                   false if headers should be displayed.
*/
public
MailList(Mailmsg[] mailmsgs, boolean showText) {
	super(showText?"Display Mail Message":"Display Mail Headers");
	if (showText) 
	  _ShowText = true;
	else 
	  _ShowHeaders = true;
	  
	setup(mailmsgs);
	setLocation(10,10);
    show();    // show the results on the screen

	}	

/**
** Constructor is called with a reference to the Face object that 
** the user wants to display.
**
** This will setup a Frame that contains a scrollable window that 
** contains an entry for every Mailmsg that is represented. 
**
**@param face - A Face object that the user selected.
*/ 
public
MailList(Face face)      {
    super("List of Selected Mail");
    
    setup(face.getMailmsgs());
    // set location on screen using relative location in window.
	// A better thing would be to place it at the corner of the face.
	// Do this on next revision.
	Point p = face.getButton().getLocation();	
	setLocation(p.x+30,p.y+30);
    show();    // show the results on the screen

}






/**
** This will setup a Frame that contains a scrollable window that 
** contains an entry for every Mailmsg that is represented. 
**
**@param mailmsgs - an array of Mailmsg objects that is to be listed.
*/
    
private void
setup(Mailmsg[] mailmsgs) { 
  
  _Mailmsgs = mailmsgs;   
	//------------
	// Handle Window closing event
	//------------
	addWindowListener(new WindowAdapter() {
		public void
		windowClosing(WindowEvent e) {
			Debug.out("Window Closing Event");
			MailList.this.dispose();
		}
	});
	_DeleteSupported = MailFaces.getRef().getMailboxRef().isDeleteSupported();
  
  	
	if (!_ShowText && !_ShowHeaders) {  
	  // if this is the list of entries (without text)
	  ScrollPane pane = buildList(mailmsgs);
	  this.add("Center",pane);  
							
  } else {
    Panel panel = buildTextPanel(mailmsgs);
    this.add("Center",panel);
	}	  
    	  
			// add the scrollable panel to main frame  
  
	pack();    // This pack is needed to format correctly with 1.0.2 on Win95
    
  Panel bottom = setupBottomButtons();
  this.add("South",bottom);
    
  this.pack();    
  this.validate();    
    
}

/**
 * Build a list of msgs with From and Subject lines
 */
private ScrollPane buildList(Mailmsg[] mailmsgs) {	 
    // build a panel (main) that will contain subpanels for all of
    // mail entries.  Make sure that all entries will fit.
	Panel main = new Panel();
	main.setBackground(Color.lightGray);
	main.setLayout(new GridLayout(0,1,10,10)); 
	int num = mailmsgs.length;
	_MailListEntries = new MailListEntry[num];
	int maxwidth=0;
	Dimension entrySize=null;
	for(int i=0; i<num; i++) {
		_MailListEntries[i] = new MailListEntry(mailmsgs[i],_DeleteSupported);
		entrySize = _MailListEntries[i].getPreferredSize();
		maxwidth = Math.max(maxwidth,entrySize.width);
	   	main.add(_MailListEntries[i]);
	   	
	}
	//maxwidth +=  this.getInsets().left + this.getInsets().right;

	main.setSize(maxwidth,num*entrySize.height);
	
	
	// We adjust the entry height by +10 because the gridlayout  
	// above sets 10 pixels between entries
	int winheight = Math.min(num,NUMSHOW)*(entrySize.height+10);	
	
	
  ScrollPane scrollPanel = new ScrollPane();  
  scrollPanel.setSize(maxwidth+8, winheight);
	//_ScrollPanel.setNumber(num); 
	scrollPanel.add(main);  
	return scrollPanel;
} 			

/**
 * Build a scrollable panel with either the 
 * text of a message or a dump of the message headers
 * 
 * @param mailmsgs list of msgs to be shown
 * @return ScrollPane object 
 */
private Panel buildTextPanel(Mailmsg[] mailmsgs) {
  Panel main = new Panel();
	main.setBackground(Color.lightGray);	  
	//int num = mailmsgs.length;
	Mailmsg mailmsg = mailmsgs[0];
	_Mailmsg = mailmsg;   
	StringBuffer sb = new StringBuffer(1024);
	sb.append("From: ");
	sb.append(mailmsg.getHeader("From"));
	sb.append("\n");
	
	sb.append("Subject: ");
	sb.append(mailmsg.getHeader("Subject"));
	sb.append("\n");
	sb.append("Size: ");
	sb.append(""+mailmsg.getSize());
	sb.append("\n\n");  
	if (_ShowText) {
	  sb.append(mailmsg.getText());
	} else {
	  sb.append(getMsgHeaders(mailmsg));
	} 
	TextArea textArea = new TextArea(sb.toString(),10,80);
	main.add(textArea);
	
	
	
  //ScrollPane scrollPanel = new ScrollPane();  
  
	//scrollPanel.add(main);  
	return main;
} 			


///**
// * Get the text of the message 
//
// * @param mailmsg msg to be shown
// * @return String of text from the message 
// */
//private String getMsgText(Mailmsg mailmsg) {
//  StringBuffer sb = new StringBuffer(1024);
//  String text = getTextContent(mailmsg);
//  sb.append(text");
//  return sb.toString();
//  
//} // getMsgText



       
/**
 * Get the Headers for the message 

 * @param mailmsg msg to be shown
 * @return String containing all of the headers 
 */
private String getMsgHeaders(Mailmsg mailmsg) {
  String[] headers = mailmsg.getHeaders();
  StringBuffer sb = new StringBuffer(headers.length*100);
  for (int i=0; i< headers.length;i++) {
    sb.append(headers[i]);
    sb.append("\n");
  }
  return sb.toString();
  
} // getMsgHeaders

/**
** Delete the current message being displayed
*/
private void 
deleteCurrent() {
	
	_Mailmsg.setDeleteFlag(true);
	MailFaces.getRef().setFlagCheckMail(true);
}
/**
** Delete the entries which have the checkbox clicked
*/
private void 
deleteChecked() {
	
	
	for (int i=0; i < _MailListEntries.length; i++) {
		if ( _MailListEntries[i].getState() )
		
			_MailListEntries[i].markDeleted(); 
	}
	
	MailFaces.getRef().setFlagCheckMail(true);
}
/**
** Delete all of the listed entries
*/
private void 
deleteAll() {
	
	
	for (int i=0; i < _MailListEntries.length; i++) {	
		_MailListEntries[i].markDeleted(); 
	}
	
	MailFaces.getRef().setFlagCheckMail(true);
}

/**
** Select the listed entries that are checked
*/
private void 
selectChecked() {
	
  Vector show = new Vector(16);	
  
	for (int i=0; i < _MailListEntries.length; i++) {	
		if ( _MailListEntries[i].getState() ) {		  
			// get the list of checked entries
		  MailListEntry entry = _MailListEntries[i];	
		  Mailmsg msg = entry.getContent();
		  show.addElement(msg);
		}
	}
	if (show.size() == 0) {
	  //If none checked, then use 1st or only  
	  MailListEntry entry = _MailListEntries[0];	
		Mailmsg msg = entry.getContent();
		show.addElement(msg);
	}
	Mailmsg[] msgs = new Mailmsg[show.size()];
	show.copyInto(msgs );
	_MailList = new MailList(msgs,true);
	
} // selectChecked

/**
** Select the same entries but display the message text
* 
*/
private void 
selectText() {
	 
	_MailList = new MailList(_Mailmsgs,true);
			
} // selectText

/**
** Select the same entries but display all of the headers
* 
*/
private void 
selectHeaders() {
	 
	_MailList = new MailList(_Mailmsgs,false);
			
} // selectHeaders

/**
** Setup the buttons that are displayed at the 
** bottom of the frame sort of like a typical 
** dialog frame
** The behaviour of these bttons is contained in 
** this rtn (in anonymous inner classes.
**
**@return Panel that contains the buttons.    
*/
private Panel
setupBottomButtons() {
    // Now setup a Panel with the "Close" and "Delete Checked Mail" buttons
    Panel panel = new Panel();
    panel.setLayout(new FlowLayout(FlowLayout.CENTER,15,15));
    setFont(new Font("Dialog",Font.BOLD,15));
 
    
 	if (_DeleteSupported) {
    if (!_ShowText && !_ShowHeaders) {
      Button delete = new Button("Delete Checked Mail");
      panel.add(delete);
      delete.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          MailList.this.deleteChecked();
          //MailList.this.removeAll();
          MailList.this.setVisible(false);
          MailList.this.dispose();

        }
      });
 
		
      Button deleteAll = new Button("Delete Listed Mail");
      panel.add(deleteAll);
      deleteAll.addActionListener(new ActionListener() {
        public void actionPerformed(ActionEvent e) {
          MailList.this.deleteAll();
          //MailList.this.removeAll();
          MailList.this.setVisible(false);
          MailList.this.dispose();
  
        }
      });
    }
	}
  if (!_ShowText && !_ShowHeaders) {
    Button select = new Button("Show Checked Mail");
    panel.add(select);
    select.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        MailList.this.selectChecked();
        //MailList.this.setVisible(false);
        //MailList.this.dispose();
      }
    });
  }
  
  if (_ShowText || 
  _ShowHeaders) {
    Button delete = new Button("Delete Mail");
    panel.add(delete);
    delete.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        MailList.this.deleteCurrent();          
        MailList.this.setVisible(false);
        MailList.this.dispose();

      }
    });    
  }
  
  if (_ShowText ) {
    Button select = new Button("Show Headers");
    panel.add(select);
    select.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        MailList.this.selectHeaders();

        MailList.this.setVisible(false);
        MailList.this.dispose();

      }
    });
  }
    
  if (_ShowHeaders ) {
    Button select = new Button("Show Text");
    panel.add(select);
    select.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        MailList.this.selectText();

        MailList.this.setVisible(false);
        MailList.this.dispose();

      }
    });
  }
  
  Button close = new Button("Cancel");
  panel.add(close);
  close.addActionListener(new ActionListener() {
    public void actionPerformed(ActionEvent e) {
      //MailList.this.removeAll();
      MailList.this.setVisible(false);
      MailList.this.dispose();
    }
  });
  
  return panel;
}



/**
** This represents a Mailmsg that is being displayed in the MailList.
** 
** It extends Panel and contains a checkbox to specify "delete" and 
** a multiline label that contains the From: header, Message Size and 
** the Subject: line. 
*/
class  MailListEntry extends Panel {
	
private	Mailmsg		_Mailmsg;
private int			width;
private int 		height;
private Checkbox	_Checkbox;

/**
** Constructor takes a Mailmsg and builds a panel that contains a checkbox to specify "delete" and 
** a multiline label that contains the From: header, Message Size and 
** the Subject: line. 
*/
MailListEntry(Mailmsg mailmsg, boolean deleteSupported) {
	
	_Mailmsg = mailmsg;
	// Create a Panel with a bunch of labels ( 3 labels for each entry)
	Font font = new Font("TimesRoman",Font.PLAIN,14);
	this.setFont(font);
	FontMetrics fm = this.getFontMetrics(this.getFont());
	
	//this.setLayout(new GridLayout(0,2,3,3));
	this.setLayout(new BorderLayout(5,5));
	
	String l0 = "From: " + mailmsg.getHeader("From") + "  Size: " + mailmsg.getSize();    
	String l1 = "     Subject: " + mailmsg.getHeader("Subject");
	
	width = Math.max( fm.stringWidth(l0) , fm.stringWidth(l1) );
	
	if (deleteSupported) {
		_Checkbox = new Checkbox(" ");
		_Checkbox.setState(mailmsg.getKillCandidate());
	
		this.add("West",_Checkbox);
	}
	MultiLineLabel ml = new MultiLineLabel(l0 + "\n" + l1 , 5,6,Label.LEFT);
	height = 2*fm.getHeight() +12;    // 2 lines + 2*spacing set by MultiLineLabel
	// The setting of width is just guesswork, we need a better method
	// insets did not help, I can only seem to get the width of the checkbox (34)
	// after the window is layed out.  
	width += 2*5+34+10;   // add the 2*margin width plus checkbox width plus fudge factor
	
	this.add("Center",ml);
	Debug.out("width=" + width + " height=" + height);
}


/**
** The user has checked the delete box for this entry and then clicked
** on "Delete marked entries", so set a flag so it will happen.
*/
void
markDeleted() {
	
	_Mailmsg.setDeleteFlag(true);
}

/**
** The user has checked the selection box for this entry and then clicked
** on "Select marked entries", so get the content.
*/
Mailmsg
getContent() {	
	
	return _Mailmsg;
	
}

/**
** Return the prefered size for this entry
*/
public Dimension
getPreferredSize() {
	
	//Debug.out(_Checkbox.preferredSize().toString());
	return new Dimension(width,height);
	
}
/**
** Return the minimum size for this entry
*/
public Dimension
getMinimumSize() {
	
	//Debug.out(_Checkbox.preferredSize().toString());
	return new Dimension(width,height);
	
}

/**
** return the state from the associated checkbox.
*/
public boolean
getState() {
	
	return _Checkbox.getState();
}

}	// end of MailListEntry
	
}  // End of MailList Class