package com.jthomas.mailfaces;

import java.awt.*;
import com.jthomas.util.*;
//---------------------------------------------
/**
 *   Display an informational message via a Dialog box along with
 *   an OK button that will clear the Dialog from the screen.
 * 
 *   It uses the MailFaces Prompter class to actually display the
 *   Dialog and process the OK or Cancel action.
 *   <pre>
 *   Example:
 *      okpressed = MsgDialog.create("MultiLine Msg\n" +
 *                                   "Press OK to retry");
 *      if (okpressed)
 *            retry();
 *      else
 *            return;
 *   </pre>
 */
//------------------------------------------------------

public class MsgDialog {

  private MsgDialog() {

  }

  //-----------------------------------------------------------
  /**
   * Create and display a modal dialog box with multiline msg.
   *	<p>
   *
   *	This Class method will create the Message Dialog box with
   *  a MultiLine message and an "OK" button.
   *  The message would use "\n" to separate the lines.
   *  It will return <b>true</b> if user presses OK button.
   *  and <b>false</b> if user presses cancel button.
   *  <pre>
   *  Example:
   *     boolean result = MsgDialog.create("Hello from:\n" + myname);
   *  </pre>
   *@param	String message (Multiline)
   *@return	boolean   true if OK pressed, false if cancel pressed
   *
   */
  //--------------------------------------------------------------  
  public static boolean create(String message) {
    Prompter p = Prompter.create();
    p.setMsgPrompt(message);
    p.showPrompt();
    int status = p.getStatus();
    if (status == Prompter.STATUS_CANCEL)
      return false;
    else
      return true;

  }

  //-----------------------------------------------------------
  /**
   * Create and display a modal dialog box with multiline msg.
   *	<p>
   *
   *	This Class method will create the Message Dialog box with
   *  a MultiLine message and an "OK" button and associate it with
   *  the specified frame.  The Dialog can be modal or non modal.
   *  The message would use "\n" to separate the lines.
   *  <pre>
   *  Example:
   *     boolean result = MsgDialog.create(myframe,"Hello from:\n" + myname, true);
   *  </pre>
   *@param    Frame  frame
   *@param	String message
   *@param    boolean  Modal
   *
   *@return	boolean   true if OK pressed, false if cancel pressed
   */
  //--------------------------------------------------------------  
  public static boolean create(Frame frame, String message, boolean modal) {
    Prompter p = Prompter.create(frame, modal);
    p.setMsgPrompt(message);
    p.showPrompt();
    int status = p.getStatus();
    if (status == Prompter.STATUS_CANCEL)
      return false;
    else
      return true;

  }
  //-----------------------------------------------------
  // Adding this makes this class self-testing
  //-----------------------------------------------------
  //public static void
  //main(String args[]) {
  //	
  //	boolean result = MsgDialog.create("This is line1\n" + "and this is line 2");
  //  Debug.out(0,"result is "+result);
  //	
  //	result = MsgDialog.create("This is a single line");
  //  Debug.out(0,"result is "+result);
  //}

} // End of MsgDialog Class