package com.jthomas.mailfaces;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import com.jthomas.util.*;


/**
 * 
 *   Object that will prompt the user for a mail header line that
 *   will be used to access the image that corresponds to that 
 *   header line. 
 *   <pre>
 *   This Object is used as follows:
 *      PromptCheck p = (PromptCheck)PromptCheck.create();    do this only once
 *      p.setDefaults(headerline,usecache,domainonly);
 *      p.show();
 *      if (p.getStatus() == PromptCheck.STATUS_OK) { 
 *           Mailmsg msg = p.getMailmsg();
 *      else
 *           handle error ...
 *
 *	 </pre>
 */


public
class PromptCheck extends Prompter  {

// Class Variables

static private PromptCheck _PromptCheck;  // The current Prompt dialog



// Instance Variables

private TextField _HeaderField;
private TextField _UserField;
private TextField _HostField;
private Checkbox  _CBox1;
private Checkbox  _CBox2;

private boolean   	_UseCache;
private boolean   	_DomainOnly;
private String		_Headerline;
private String      _User;
private String      _Host;


//
// Constructor for this class
// It calls the constructor for the Dialog super class
//
private
PromptCheck(Frame frame,String prompt,boolean modal) {
    super(frame,prompt,modal);
	
}


//---------------------------------------------------
// create()  -> reference to PromptCheck object
//   This is a Class method that the user of PromptCheck will
//   invoke to build a PromptCheck dialog object
//
//   This method should be invoked only once to build a reuseable
//   PromptCheck object
//      PromptCheck p = (PromptCheck)PromptCheck.create();
//------------------------------------------------------


public static Prompter
create() {
    Debug.out("PromptCheck.create()" );
	if(_DialogFrame == null) 
    	_DialogFrame = new Frame("Dialog");
    	
    if (_PromptCheck == null)	
    	_PromptCheck = new PromptCheck(_DialogFrame,"Prompt",true);
    _PromptCheck._Modal = true;	 
   	// Return a reference to the One and Only PromptCheck Dialog instance
    return _PromptCheck;
}

//---------------------------------------------------
// setCheckDefaults(headerline,usecache,domainonly)  
//   This will set the Default values
//   and format the contents of the window.  
//------------------------------------------------------

public void
setCheckDefaults(String headerline, boolean usecache, boolean domainonly) {

	// Handle null parameters
	headerline = (headerline == null)?"from: ":headerline;
	
    removeAll(); 		// Remove components from last time.
    this.setLayout(new BorderLayout(5,5));
    
    Panel main = new Panel();
    main.setLayout(new BorderLayout(5,5));

    // Setup the line(s) at the top of the window
	
    Panel toppanel = new Panel();
    toppanel.setFont(new Font("TimesRoman",Font.BOLD,16));	
    MultiLineLabel topline = new MultiLineLabel("     Verify Icon Selection\n"+ 
    											"  Enter a Mail Header or the\n" +
                                                "  From: Userid@ Host address ");
    toppanel.add(topline);
	main.add("North",toppanel);
	
	
    // Setup the prompt lines
    
    Panel center = new Panel();
    center.setLayout(new GridLayout(3,1,10,10));
    center.setFont(new Font("Courier",Font.BOLD,14));
 
    Panel p2 = new Panel();
    p2.setLayout(new FlowLayout(FlowLayout.LEFT)); 
    Label l2 = new Label("Mail Header:");
    _HeaderField = new TextField(40);
    _HeaderField.setText(headerline);
    p2.add(l2);
    p2.add(_HeaderField);
    center.add(p2);

    Panel p3 = new Panel();
    p3.setLayout(new FlowLayout(FlowLayout.LEFT)); 
    Label l3 = new Label("From: Userid@HostDomain ");
    _UserField = new TextField(10);
    Label l4 = new Label(" @ ");
    _HostField = new TextField(20);
    
    p3.add(l3);
    p3.add(_UserField);
    p3.add(l4);
    p3.add(_HostField);
    center.add(p3);

    
    Panel p4 = new Panel();
    p4.setLayout(new FlowLayout(FlowLayout.CENTER)); 
    _CBox1 = new Checkbox("Use Cache");
    _CBox2 = new Checkbox("HostDomain only");
    p4.add(_CBox1);
    
    _CBox1.addItemListener(new ItemListener() {
		public void
		itemStateChanged(ItemEvent e) { 
			PromptCheck.this._UseCache = _CBox1.getState();	
		}
    } );	

    p4.add(_CBox2);
    _CBox2.addItemListener(new ItemListener() {
		public void
		itemStateChanged(ItemEvent e) { 
			PromptCheck.this._DomainOnly = _CBox2.getState();	
		}
    } );	

    center.add(p4);
  
    _HeaderField.requestFocus();
        
	main.add("Center",center);
    this.add("Center",main);
	
    
    this.pack();    // This pack is needed to format correctly with 1.0.2 on Win95
 
	Panel okPanel = super.setupButtons();
	this.add("South",okPanel);
	this.pack();
    //Debug.out("this - " + this.size().toString());
    	
    //_PromptCheck.move(200,200);       // Where to put it on Users screen
    Dimension size = this.getSize();
    this.setSize(size.width+30,size.height+5);

}

public Mailmsg
getMailmsg() {
	if ( _Status != STATUS_OK ) 
		return null;
	Debug.out("getMailmsg()");
	
	_Headerline   = _HeaderField.getText();
	_User = _UserField.getText();
	_Host = _HostField.getText();
	
	_UseCache = _CBox1.getState();
	_DomainOnly = _CBox2.getState();
	
	// Build a fake mailmsg
	Mailmsg mailmsg = new Mailmsg(0);
	String[] headers = new String[2];
	int i=0;
	if (_Headerline.length() > 0) {
		headers[i] = _Headerline;
		i++;
	}
	mailmsg.putHeader(null,_Headerline);
	if (_Host.length() > 0) {
		mailmsg.putHeader("FROM", _User + "@" + _Host);
	} else 
		if (_User.length() > 0) 
			mailmsg.putHeader("FROM", _User);

	
	mailmsg.setSize(0);
	mailmsg.setKey("Generated");
	return mailmsg;
}	

public boolean
getUseCache() {
	return _UseCache;
}

public boolean
getDomainOnly() {
	return _DomainOnly;
}




//-----------------------------------------------------
// Adding this makes this class self-testing
//-----------------------------------------------------
public static void
main(String args[]) {
	
	
	Debug.setDebugOn(true);
	if (args.length > 0) {	// 1st argument is debug output file name
		Debug.setDebugFile(args[0]);
	}
	
	PromptCheck p;
	
	p = (PromptCheck)PromptCheck.create();    //do this only once
    
	p.setCheckDefaults("from: jthomas@cruzio.com",false,false);
    p.showPrompt();
    if ( p.getStatus() == PromptCheck.STATUS_OK ) {
    
		Debug.out("result=" + p.getMailmsg());
		Debug.out("Status=" + p._Status);
    } else {
    	Debug.out("Cancel?");
    	Debug.out("result=" + p.getMailmsg());
		Debug.out("Status=" + p._Status);
    }
	System.exit(0);
}
   
} //End of PromptCheck class