package com.jthomas.mailfaces;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import com.jthomas.util.*;



/**
 * PromptLogin.java 
 *   Object that will prompt the user for Login info (Host,user,password. 
 * <pre>  
 *   This Object is used as follows:
 *      PromptLogin p = PromptLogin.create();    do this only once
 *      p.setDefaults(type,host,user,password);
 *      p.show();
 *      if (p._Status == PromptLogin.STATUS_OK) { 
 *           String type = p.getType();
 *           String user = p.gerUser(); etc
 *      else
 *           System.exit(0);
 *
 *   If used from within an action method, then the
 *   call to p.getType() should be done outside of
 *   of the action thread.  
 *	</pre>
 */


public
class PromptLogin extends Prompter  {

// Class Variables

static private PromptLogin		_PromptLogin;      // The current Prompt dialog



// Instance Variables

private Choice    _TypeChoice;
private TextField _HostField;
private TextField _UserField;
private TextField _PassField;

private String		_Type;
private String		_Host;
private String		_User;
private String		_Pass;
//
// Constructor for this class
// It calls the constructor for the Dialog super class
//
private
PromptLogin(Frame frame,String prompt,boolean modal) {
    super(frame,prompt,modal);
	
}


//---------------------------------------------------
/**
** create()  -> reference to PromptLogin object
//   This is a Class method that the user of PromptLogin will
//   invoke to build a PromptLogin dialog object
//
//   This method should be invoked only once to build a reuseable
//   PromptLogin object
*/
//------------------------------------------------------


public static Prompter
create() {
    Debug.out("PromptLogin.create()" );
	if(_DialogFrame == null) 
    	_DialogFrame = new Frame("Dialog");
    	
    if (_PromptLogin == null)	
    	_PromptLogin = new PromptLogin(_DialogFrame,"Prompt",true);
    _PromptLogin._Modal = true;	 
   	// Return a reference to the One and Only PromptLogin Dialog instance
    return _PromptLogin;
}

//---------------------------------------------------
/**
** setLoginDefaults(type,host,user,password)  
**   This will set the Prompt string and Default value
**   and format the contents of the window.  
*/
//------------------------------------------------------

public void
setLoginDefaults(String type, String host, String user, String password) {

	// Handle null parameters
	type = (type == null)?"POP3":type;
	host = (host == null)?"":host;
	user = (user == null)?"":user;
	password = (password == null)?"":password;
    removeAll(); 		// Remove components from last time.
    this.setLayout(new BorderLayout(5,5));
    
    Panel main = new Panel();
    main.setLayout(new BorderLayout(5,5));

    // Setup the line(s) at the top of the window
	
    Panel toppanel = new Panel();
    toppanel.setFont(new Font("TimesRoman",Font.BOLD,16));	
    Label topline = new Label("Enter Login Information for the Mail Server");
    toppanel.add(topline);
	main.add("North",toppanel);
	
	
    // Setup the prompt lines
    
    Panel center = new Panel();
    center.setLayout(new GridLayout(3,1,10,10));
    center.setFont(new Font("Courier",Font.BOLD,14));
 
    Panel p2 = new Panel();
    p2.setLayout(new FlowLayout(FlowLayout.LEFT)); 
    Label l2 = new Label("Mail Host:");
    _HostField = new TextField(33);
    _HostField.setText(host);
    p2.add(l2);
    p2.add(_HostField);
    center.add(p2);

    Panel p3 = new Panel();
    Panel p3a = new Panel();
    Panel p3b = new Panel();
    
    p3.setLayout(new FlowLayout(FlowLayout.LEFT));
    p3a.setLayout(new FlowLayout(FlowLayout.LEFT));
    p3b.setLayout(new FlowLayout(FlowLayout.LEFT));
    Label l3 = new Label("Mail User:");
    _UserField = new TextField(10);
    _UserField.setText(user);
    
    _TypeChoice = new Choice();
    _TypeChoice.addItem("POP3");
    //_TypeChoice.addItem("JPOP");
    //_TypeChoice.addItem("APOP");
    _TypeChoice.addItem("IMAP");
    // Only show HotMail and Yahoo Mail if classes are present
//    try {
//      Class.forName("com.jthomas.mailfaces.htmlmail.FaceMailboxYahoo");
//      _TypeChoice.addItem("HotMail");
//    } catch (Throwable e) {
//      // just don't show it
//    }
//    try {
//      Class.forName("com.jthomas.mailfaces.htmlmail.FaceMailboxYahoo");
//      _TypeChoice.addItem("Yahoo");
//    } catch (Throwable e) {
//      // just don't show it
//    }
	

    _TypeChoice.select(type);
    p3a.add(l3);
    p3a.add(_UserField);
    p3b.add(new Label("Server Type:"));
    p3b.add(_TypeChoice);
    p3.add(p3a);
    p3.add(p3b);
    center.add(p3);

    Panel p4 = new Panel();
    p4.setLayout(new FlowLayout(FlowLayout.LEFT)); 
    Label l4 = new Label(" Password:");
    _PassField = new TextField(10);
    _PassField.setText(password);
    _PassField.setEchoChar('*');
    
    p4.add(l4);
    p4.add(_PassField);
    center.add(p4);
    _PassField.addActionListener(new ActionListener() {
    	public void
    	actionPerformed(ActionEvent e) {
    		_Type   = _TypeChoice.getSelectedItem();
			_Host   = _HostField.getText();
			_User   = _UserField.getText();
			_Pass   = _PassField.getText();		
			_Status = STATUS_OK;
			PromptLogin.this.setVisible(false);
    	}
    } );  
    
	main.add("Center",center);
    this.add("Center",main);
	
    
    this.pack();    // This pack is needed to format correctly with 1.0.2 on Win95
    //Debug.out("this - " + this.size().toString());
    //Debug.out("main - " + main.preferredSize().toString());
    //Debug.out("center - " + center.preferredSize().toString());
    //Debug.out("p2 - " + p2.preferredSize().toString());
    //Debug.out("p3 - " + p3.preferredSize().toString());
    //Debug.out("l3 - " + l3.preferredSize().toString());
    //Debug.out("_UserField - " + _UserField.preferredSize().toString());
    //Debug.out("_TypeChoice - " + _TypeChoice.preferredSize().toString());
    //Debug.out("p4 - " + p4.preferredSize().toString());
    // Now setup a Panel with the OK and Cancel buttons
    Panel panel = new Panel();
    panel.setLayout(new FlowLayout(FlowLayout.CENTER,15,15));
    setFont(new Font("Dialog",Font.BOLD,15));
    Button okButton = new Button("  OK  ");
    panel.add(okButton);
    okButton.addActionListener(new ActionListener() {
    	public void
    	actionPerformed(ActionEvent e) {
    		_Type   = _TypeChoice.getSelectedItem();
			_Host   = _HostField.getText();
			_User   = _UserField.getText();
			_Pass   = _PassField.getText();
			_Status = STATUS_OK;
			PromptLogin.this.setVisible(false);
    	}
    });
    Button cancelButton = new Button("Cancel");
    panel.add(cancelButton);
    cancelButton.addActionListener(new ActionListener() {
    	public void
    	actionPerformed(ActionEvent e) {
    		_Type   = null;
    		_Host   = null;
			_User   = null;
			_Pass   = null;
			_Status = STATUS_CANCEL;
			PromptLogin.this.setVisible(false);
    	}
    });
    
    this.add("South",panel);
    
    this.pack();
    //Debug.out("this - " + this.size().toString());
    this.validate();    
	//Debug.out(this.size().toString());
	
    //_PromptLogin.move(200,200);       // Where to put it on Users screen
    Dimension size = this.getSize();
    this.setSize(size.width+30,size.height+5);
    
    // Set keyboard focus to the 1st field that is blank
	if ( host.length() == 0)
    	_HostField.requestFocus();
    else if ( user.length() == 0)
    	_UserField.requestFocus();
    else
    	_PassField.requestFocus();
}

public String
getType() {
	if ( _Status == STATUS_OK ) 
		return _Type;
	else  						// Return null if Cancel button pressed
		return null;
}	

public String
getHost() {
	if ( _Status == STATUS_OK ) 
		return _Host;
	else  						// Return null if Cancel button pressed
		return null;
}
public String
getUser() {
	if ( _Status == STATUS_OK ) 
		return _User;
	else  						// Return null if Cancel button pressed
		return null;
}
public String
getPass() {
	if ( _Status == STATUS_OK ) 
		return _Pass;
	else  						// Return null if Cancel button pressed
		return null;
}



//-----------------------------------------------------
// Adding this makes this class self-testing
//-----------------------------------------------------
public static void
main(String args[]) {
	
	
	Debug.setDebugOn(true);
	if (args.length > 0) {	// 1st argument is debug output file name
		Debug.setDebugFile(args[0]);
	}
	
	PromptLogin p;
	
	p = (PromptLogin)PromptLogin.create();    //do this only once
    
	p.setLoginDefaults("POP3","mail.cruzio.com","jthomas","");
    p.showPrompt();
    if ( p.getStatus() == PromptLogin.STATUS_OK )
    
	Debug.out("result=" + p.getType() + " " + p.getHost() + " " + p.getUser() + " " + p.getPass());
	Debug.out("Status=" + p._Status);
	
	System.exit(0);
}
   
} //End of PromptLogin class