package com.jthomas.util;


import java.io.*;
import java.util.*;

/**
** Log information with time stamp
** Usage:
**
** To have Log output displayed
**     Log.setLogOn(true,filename)
**
** To produce Log output just specify an identifier and a 
** string as a parameters to the Class method "Log.out(String id,String x)"
** The idea is that the "id" string should be unique so one could search for it
** 
** For example:
**     Log.out("Options01", loginfo);
*/

public class Log {


static public boolean	LogOn=false; 		// Log On switch

static String		LogFile="";  		// Log output

static public
		PrintWriter LogOut=null;


//------------------------------------------------------
// Private Constructor
//   The Log class only has static Class methods so it should not
//   need a constructor.  Make it private just to warn the programmer.
//-----------------------------------------------------

private
Log() {
}


		
//------------------------------------------------------
/**
 *Method: setLogOn(boolean switch)
 *
 * Method to let caller turn the Log switch on or off
 */
public static void
setLogOn(boolean OnOff,String file) {
	LogOn = OnOff;
	LogFile = file;
	try {
		
		// Create output print stream and specify append option and autoflush
		LogOut = new PrintWriter(new FileOutputStream(file,true),true);
	} catch (IOException e) {
		LogOut = null;
		System.err.println("Unable to setup Log output file");
	}
	
}


//------------------------------------------------------
/**
 *Method: Log.out(String string)
 *
 *  If LogOn switch set, display Log info
 *
 */
public static void
out(String id, String logstr) {
    
	if ( LogOn) {
		String logtime = (new Date()).toString().substring(0,19);		
		if (LogOut != null) {    		// Write to Log File
			String line = logtime + " " +id + ": " + logstr ;
			//System.out.println(line);
			LogOut.println(line + '\r');
			LogOut.flush();		
		}

	}
} 
 
//------------------------------------------------------
/**
 *Method: Log.out(id, throwable)
 *
 *  If LogOn switch set, display stacktrace
 *
 */
public static void
out(String id, Throwable e) {
    
	if ( LogOn) {
		String logtime = (new Date()).toString().substring(0,19);		
		if (LogOut != null) {    		// Write to Log File
			String line = logtime + " " +id + ": " + e.getMessage() ;
			
			LogOut.println(line + '\r');
			e.printStackTrace(LogOut);
			LogOut.flush();		
		}

	}
}  

public static void
exception(Exception e) {
	out("Exception",e.getMessage());
	e.printStackTrace(LogOut);
	LogOut.flush();
}

public static void 
main( String[] argv) {
	
	Log.setLogOn(true,"log.txt");
	Log.out("test","data");
}		
}  // End of Log class